[![Build Status](https://travis-ci.org/Terralego/django-terra-utils.svg?branch=master)](https://travis-ci.org/Terralego/django-terra-utils)
[![codecov](https://codecov.io/gh/Terralego/django-terra-utils/branch/master/graph/badge.svg)](https://codecov.io/gh/Terralego/django-terra-utils)
[![Maintainability](https://api.codeclimate.com/v1/badges/5e60cc95c683ab4fb31c/maintainability)](https://codeclimate.com/github/Terralego/django-terra-utils/maintainability)

https://django-terra-utils.readthedocs.io/en/latest/

Helpers and default configuration endpoints for terralego frontend application.
